STonKGs |release| Documentation
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   installation
   cli
   nlp_baseline
   kg_baseline
   stonkgs
   training

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
